"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MongoKeyValue = void 0;
const mongodb_1 = require("mongodb");
class MongoKeyValue {
    constructor() {
        this.description = {
            displayName: 'MongoKeyValue',
            name: 'mongoKeyValue',
            icon: 'file:httpbin.svg',
            group: ['transform'],
            version: 1,
            subtitle: '={{$parameter["action"] + ": " + $parameter["key"]}}',
            description: 'Interact with MongoKeyValue API',
            defaults: {
                name: 'MongoKeyValue',
            },
            inputs: ['main'],
            outputs: ['main'],
            credentials: [
                {
                    name: 'mongoKeyValueApi',
                    required: true,
                },
            ],
            properties: [
                {
                    displayName: 'Action',
                    name: 'action',
                    type: 'options',
                    noDataExpression: true,
                    options: [
                        {
                            name: 'Get',
                            value: 'get',
                        },
                        {
                            name: 'Set',
                            value: 'set',
                        },
                    ],
                    default: 'get',
                },
                {
                    displayName: 'Key Name or ID',
                    name: 'key',
                    type: 'options',
                    description: 'Choose from the list, or specify an ID using an <a href="https://docs.n8n.io/code-examples/expressions/">expression</a>',
                    default: '',
                    typeOptions: {
                        loadOptionsMethod: 'getKeys',
                    },
                },
                {
                    displayName: 'New Key Name',
                    name: 'newKey',
                    type: 'string',
                    default: '',
                    displayOptions: {
                        show: {
                            action: ['set'],
                        },
                    },
                },
                {
                    displayName: 'Value',
                    name: 'value',
                    type: 'json',
                    default: '',
                    displayOptions: {
                        show: {
                            action: ['set'],
                        },
                    },
                },
                {
                    displayName: 'Default Value',
                    name: 'defaultValue',
                    type: 'json',
                    default: '',
                    displayOptions: {
                        show: {
                            action: ['get'],
                        },
                    },
                },
            ],
        };
        this.methods = {
            loadOptions: {
                async getKeys() {
                    const mongoKeyValueApi = this.getCredentials('mongoKeyValueApi');
                    const mongoKeyValueConnectionString = await mongoKeyValueApi;
                    const client = new mongodb_1.MongoClient(mongoKeyValueConnectionString.mongoDbConnectionString);
                    const database = client.db('n8n-kv');
                    const collection = database.collection('kv-store');
                    const keys = await collection.find({}, { projection: { _id: 0, key: 1 } }).toArray();
                    return [
                        {
                            name: 'Select a Key or Create a New One Below',
                            value: '',
                        },
                        ...keys.map((key) => ({
                            name: key.key,
                            value: key.key,
                        })),
                    ];
                },
            },
        };
    }
    async execute() {
        const items = this.getInputData();
        const mongoKeyValueApi = this.getCredentials('mongoKeyValueApi');
        const mongoKeyValueConnectionString = await mongoKeyValueApi;
        const client = new mongodb_1.MongoClient(mongoKeyValueConnectionString.mongoDbConnectionString);
        const database = client.db('n8n-kv');
        const collection = database.collection('kv-store');
        const key = this.getNodeParameter('key') ||
            this.getNodeParameter('newKey');
        if (this.getNodeParameter('action') === 'set') {
            const result = this.getNodeParameter('value');
            await collection.updateOne({ key: key }, {
                $set: { value: result },
            }, { upsert: true });
            items[0].json = {
                result: result,
            };
        }
        else {
            const result = (await collection.findOne({
                key: key,
            }));
            items[0].json = {
                result: (result === null || result === void 0 ? void 0 : result.value)
                    ? result.value
                    : this.getNodeParameter('defaultValue'),
            };
        }
        return [this.helpers.returnJsonArray(items)];
    }
}
exports.MongoKeyValue = MongoKeyValue;
//# sourceMappingURL=MongoKeyValue.node.js.map